"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs_1 = require("../lib/utils/fs");
const util_1 = require("../lib/utils/util");
class DiffEnv extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(DiffEnv);
            const prev = (0, util_1.parseEnv)(flags['prev-env']);
            const after = (0, util_1.parseEnv)(flags['after-env']);
            const env = [];
            for (const [k, v] of Object.entries(after)) {
                if (prev[k] !== after[k]) {
                    env.push(`${k}=${v}`);
                }
            }
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, env.join('\n'), '.env');
            }
            else {
                console.log(env.join('\n'));
            }
        });
    }
}
exports.default = DiffEnv;
DiffEnv.description = 'Output diff env';
DiffEnv.examples = [
    `
  $ typed-env diff-env -p "$(prev_env)" -a "$(env)"

  output:
       prev_env: {a: 1} env: {b: 1} -> {b: 1}
  `,
];
DiffEnv.flags = {
    'prev-env': core_1.Flags.string({
        char: 'p',
        description: 'enter current env json',
        required: true,
    }),
    'after-env': core_1.Flags.string({
        char: 'a',
        description: 'enter change env json',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
