"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const generate_typed_env_call_usage_report_1 = require("../lib/generate-typed-env-call-usage-report");
const fs_1 = require("../lib/utils/fs");
class GenTypedEnvCallUsageReport extends core_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = yield this.parse(GenTypedEnvCallUsageReport);
            const info = (0, generate_typed_env_call_usage_report_1.generateTypedEnvCallUsageReport)({
                sourceFilePath: flags['source-file'],
                options: { tsConfigFilePath: flags.tsconfig },
            });
            if (flags.output) {
                (0, fs_1.outputFile)(flags.output, JSON.stringify(info, null, 4), 'typed-env-call-usage-report.json');
            }
            else {
                console.log(info);
            }
        });
    }
}
exports.default = GenTypedEnvCallUsageReport;
GenTypedEnvCallUsageReport.description = 'Generate typed-env call usage report';
GenTypedEnvCallUsageReport.examples = [
    `$ typed-env gen-typed-env-call-usage-report -s ./src/index.ts -t ./tsconfig.json -o ./src/typed-env-call-usage-report.json`,
];
GenTypedEnvCallUsageReport.flags = {
    'source-file': core_1.Flags.string({
        char: 's',
        description: 'enter the file path to check',
        required: true,
    }),
    tsconfig: core_1.Flags.string({
        char: 't',
        description: 'enter the tsconfig.json path',
        required: true,
    }),
    output: core_1.Flags.string({
        char: 'o',
        description: 'enter the output file path',
    }),
};
